import { ConversionTypeEnum } from './ConversionTypeEnum';
import { IConversionOption } from './IConversionOption';
/**
 * A Utility class that has several static methods to assist in development.
 *
 * @class Util
 * @author Robert S. (www.codeBelt.com)
 * @static
 */
export declare class Util {
    /**
     * Keeps track of the count for the uniqueId method.
     *
     * @property _idCounter
     * @type {int}
     * @private
     * @static
     */
    private static _idCounter;
    /**
     * Generates a unique ID. If a prefix is passed in, the value will be appended to it.
     *
     * @method uniqueId
     * @param [prefix] {string} The string value used for the prefix.
     * @returns {init|string} Returns the unique identifier.
     * @public
     * @static
     * @example
     *      let property = Util.uniqueId();
     *      // 1
     *
     *      let property = Util.uniqueId('prefixName_');
     *      // prefixName_1
     */
    static uniqueId(prefix?: string): any;
    /**
     * Removes a list of properties from an object.
     *
     * @method deletePropertyFromObject
     * @param object {Object} The object you want to remove properties from.
     * @param value {string|Array.<string>} A property name or an array of property names you want to remove from the object.
     * @returns {any} Returns the object passed in without the removed the properties.
     * @public
     * @static
     * @example
     *      let obj = { name: 'Robert', gender: 'male', phone: '555-555-5555' }
     *
     *      Util.deletePropertyFromObject(obj, ['phone', 'gender']);
     *
     *      // { name: 'Robert' }
     */
    static deletePropertyFromObject(object: any, value: string | string[]): any;
    /**
     * Makes a clone of an object.
     *
     * @method clone
     * @param src {Object} The object you to clone.
     * @param renamePropertyName {(keyName: string) => string} Optional function to rename property names
     * @returns {any} Returns a clone object of the one passed in.
     * @public
     * @static
     * @example
     *      let cloneOfObject = Util.clone(obj);
     */
    static clone(src: any, renamePropertyName?: (keyName: string) => string): any;
    /**
     * Converts a string or number to a boolean.
     * @example
     *      Util.toBoolean("FALSE");
     *      // false
     *
     *      Util.toBoolean("off");
     *      // false
     *
     *      Util.toBoolean(0);
     *      // false
     *
     *      Util.toBoolean(undefined);
     *      // false
     */
    static toBoolean(value: null | undefined | string | number | boolean): boolean;
    static validConversionOptionNames(data: object, conversionOptions?: IConversionOption): void;
    static convertDataToConversionType(propertyData: null | string | number | boolean, conversionType: ConversionTypeEnum): null | string | number | boolean | object;
    /**
     * Check the data is an object with properties.
     */
    static isObjectWithProperties(data: any): boolean;
    /**
     * Check if the data is an object.
     */
    static isObject(data: any): boolean;
}
